dtw_loss_functions.soft_dtw_implementations.soft_dtw_cuda_ron.cuda.kernels module — dtw_loss_functions documentation

# dtw_loss_functions.soft_dtw_implementations.soft_dtw_cuda_ron.cuda.kernels module

dtw_loss_functions.soft_dtw_implementations.soft_dtw_cuda_ron.cuda.kernels.softdtw_backward_kernel_legacy(D_pad, R, inv_gamma, bandwidth, max_i, max_j, n_passes, E)

dtw_loss_functions.soft_dtw_implementations.soft_dtw_cuda_ron.cuda.kernels.softdtw_backward_log_cuda(D, R, inv_gamma, bandwidth, max_i, max_j, n_passes, logE)

  D: (B, N+2, M+2) padded R: (B, N+2, M+2) padded (with boundary conditions already set) logE: (B, N+2, M+2) padded, initialized to -inf with logE[:,-1,-1]=0

dtw_loss_functions.soft_dtw_implementations.soft_dtw_cuda_ron.cuda.kernels.softdtw_backward_log_diag_cuda(Dp, R, logE, inv_gamma, bandwidth, N, M, p)

dtw_loss_functions.soft_dtw_implementations.soft_dtw_cuda_ron.cuda.kernels.softdtw_backward_log_diag_sqeuclid_cuda(X, Y, R, logE, inv_gamma, bandwidth, N, M, D, p)

dtw_loss_functions.soft_dtw_implementations.soft_dtw_cuda_ron.cuda.kernels.softdtw_forward_diag_cuda(D, R, gamma, bandwidth, N, M, p)

dtw_loss_functions.soft_dtw_implementations.soft_dtw_cuda_ron.cuda.kernels.softdtw_forward_diag_sqeuclid_cuda(X, Y, R, gamma, bandwidth, N, M, D, p)

dtw_loss_functions.soft_dtw_implementations.soft_dtw_cuda_ron.cuda.kernels.softdtw_forward_kernel(D, gamma, bandwidth, max_i, max_j, n_passes, R)